@@ -12,7 +12,7 @@
  *      'port'           The port used to connect to the ssh2 server if other
  *                       than 22.</pre>
  *
- * $Horde: framework/VFS/lib/VFS/ssh2.php,v 1.1.2.12 2009/01/06 15:23:47 jan Exp $
+ * $Horde: framework/VFS/lib/VFS/ssh2.php,v 1.1.2.17 2010/12/07 23:56:15 bklang Exp $
  *
  * Copyright 2006-2009 The Horde Project (http://www.horde.org/)
  *
@@ -118,6 +118,7 @@ class VFS_ssh2 extends VFS {
             return $file;
         }
 
+        clearstatcache();
         $size = filesize($file);
         if ($size === 0) {
             return '';
@@ -153,7 +154,7 @@ class VFS_ssh2 extends VFS {
         }
         register_shutdown_function(create_function('', 'unlink(\'' . addslashes($localFile) . '\');'));
 
-        if (!@ssh2_scp_recv($this->_stream, escapeshellarg($this->_getPath($path, $name)), $localFile)) {
+        if (!$this->_recv($this->_getPath($path, $name), $localFile)) {
             return PEAR::raiseError(sprintf(_("Unable to open VFS file \"%s\"."), $this->_getPath($path, $name)));
         }
 
@@ -202,13 +203,13 @@ class VFS_ssh2 extends VFS {
             return $res;
         }
 
-        if (!@ssh2_scp_send($this->_stream, $tmpFile, escapeshellarg($this->_getPath($path, $name)))) {
+        if (!$this->_send($tmpFile, $this->_getPath($path, $name)))  {
             if ($autocreate) {
                 $result = $this->autocreatePath($path);
                 if (is_a($result, 'PEAR_Error')) {
                     return $result;
                 }
-                if (!@ssh2_scp_send($this->_stream, $tmpFile, escapeshellarg($this->_getPath($path, $name)))) {
+                if (!$this->_send($tmpFile, $this->_getPath($path, $name))) {
                     return PEAR::raiseError(sprintf(_("Unable to write VFS file \"%s\"."), $this->_getPath($path, $name)));
                 }
             } else {
@@ -669,6 +670,25 @@ class VFS_ssh2 extends VFS {
         return $files;
     }
 
+    /**
+     * Returns if a given file or folder exists in a folder.
+     *
+     * @param string $path  The path to the folder.
+     * @param string $name  The file or folder name.
+     *
+     * @return boolean  True if it exists, false otherwise.
+     */
+    function exists($path, $name)
+    { 
+        $conn = $this->_connect();
+        if (is_a($conn, 'PEAR_Error')) {
+            return $conn;
+        }
+
+        return !(ssh2_sftp_stat($this->_sftp, ssh2_sftp_realpath($this->_sftp, $path) . '/' . $name) === false);
+    }
+
+
     /**
      * Returns a sorted list of folders in the specified directory.
      *
@@ -758,13 +778,18 @@ class VFS_ssh2 extends VFS {
             }
         } else {
             $tmpFile = $this->_getTempFile();
-            $fetch = @ssh2_scp_recv($this->_stream, escapeshellarg($orig), $tmpFile);
+            $fetch = $this->_recv($orig, $tmpFile);
             if (!$fetch) {
                 unlink($tmpFile);
                 return PEAR::raiseError(sprintf(_("Failed to copy from \"%s\"."), $orig));
             }
 
-            if (!@ssh2_scp_send($this->_stream, $tmpFile, escapeshellarg($this->_getPath($dest, $name)))) {
+            $res = $this->_checkQuotaWrite('file', $tmpFile);
+            if (is_a($res, 'PEAR_Error')) {
+                return $res;
+            }
+
+            if (!$this->_send($tmpFile, $this->_getPath($dest, $name))) {
                 unlink($tmpFile);
                 return PEAR::raiseError(sprintf(_("Failed to copy to \"%s\"."), $this->_getPath($dest, $name)));
             }
@@ -950,4 +975,51 @@ class VFS_ssh2 extends VFS {
         return true;
     }
 
+    /**
+     * Sends local file to remote host.
+     * This function exists because the php_scp_* functions doesn't seem to work on some hosts.
+     *
+     * @access private
+     *
+     * @param string $local   Full path to the local file.
+     * @param string $remote  Full path to the remote location.
+     *
+     * @return boolean TRUE on success, FALSE on failure.
+     */
+    function _send($local, $remote)
+    {
+        return @copy($local, $this->_wrap($remote));
+    }
+
+    /**
+     * Receives file from remote host.
+     * This function exists because the php_scp_* functions doesn't seem to work on some hosts.
+     *
+     * @access private
+     *
+     * @param string $local  Full path to the local file.
+     * @param string $remote Full path to the remote location.
+     *
+     * @return boolean TRUE on success, FALSE on failure.
+     */
+    function _recv($remote, $local)
+    {
+        return @copy($this->_wrap($remote), $local);
+    }
+
+    /**
+     * Generate a stream wrapper file spec for a remote file path
+     *
+     * @access private
+     *
+     * @param string $remote  Full path to the remote location
+     *
+     * @return string  A full stream wrapper path to the remote location
+     */
+    function _wrap($remote)
+    {
+        return 'ssh2.sftp://' . $this->_params['username'] . ':' . $this->_params['password']
+            . '@' . $this->_params['hostspec'] . ':' . $this->_params['port'] . ssh2_sftp_realpath($this->_sftp, $remote);
+    }
+
 }
